@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,12 +24,13 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QTabWidget>
+#include <QStandardPaths>
 #include <qtest.h>
 
 KDebugSettingsDialogTest::KDebugSettingsDialogTest(QObject *parent)
     : QObject(parent)
 {
-
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 KDebugSettingsDialogTest::~KDebugSettingsDialogTest()
