@@ -34,16 +34,16 @@ public:
 
     void fillList(const LoggingCategory::List &list);
     LoggingCategory::List rules();
-private Q_SLOTS:
+private:
     void slotRemoveRule();
     void slotAddRule();
     void slotEditRule();
     void updateButtons();
-private:
-    QListWidget *mListWidget;
-    QPushButton *mAddRule;
-    QPushButton *mEditRule;
-    QPushButton *mRemoveRule;
+
+    QListWidget *mListWidget = nullptr;
+    QPushButton *mAddRule = nullptr;
+    QPushButton *mEditRule = nullptr;
+    QPushButton *mRemoveRule = nullptr;
 };
 
 #endif // CUSTOMDEBUGSETTINGSPAGE_H
