@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -42,14 +42,14 @@ public:
     LoggingCategory rule();
 private:
     QString mCategory;
-    CategoryTypeComboBox *mCategoryTypeCombobox;
+    CategoryTypeComboBox *mCategoryTypeCombobox = nullptr;
 };
 
 class KDEApplicationTreeListWidget : public QTreeWidget
 {
     Q_OBJECT
 public:
-    explicit KDEApplicationTreeListWidget(QWidget *parent = Q_NULLPTR);
+    explicit KDEApplicationTreeListWidget(QWidget *parent = nullptr);
     ~KDEApplicationTreeListWidget();
 
     void deSelectAllDebugCategories();
