@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,17 +35,17 @@ class KDebugSettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit KDebugSettingsDialog(QWidget *parent = Q_NULLPTR);
+    explicit KDebugSettingsDialog(QWidget *parent = nullptr);
     ~KDebugSettingsDialog();
 
-private Q_SLOTS:
+private:
     void slotAccepted();
     void slotHelpRequested();
     void slotApply();
     void slotSaveAs();
     void slotLoad();
     void slotInsertCategories();
-private:
+
     void readQtLoggingFile();
     bool saveRules(const QString &path);
     bool saveInQtLogging();
@@ -54,11 +54,11 @@ private:
     void readConfig();
     KdeLoggingCategory::List mCategoriesList;
     RenameCategory::List mRenameCategoriesList;
-    QTabWidget *mTabWidget;
-    KDEApplicationDebugSettingPage *mKdeApplicationSettingsPage;
-    CustomDebugSettingsPage *mCustomSettingsPage;
-    EnvironmentSettingsRulesPage *mEnvironmentSettingsRulesPage;
-    CategoryWarning *mCategoryWarning;
+    QTabWidget *mTabWidget = nullptr;
+    KDEApplicationDebugSettingPage *mKdeApplicationSettingsPage = nullptr;
+    CustomDebugSettingsPage *mCustomSettingsPage = nullptr;
+    EnvironmentSettingsRulesPage *mEnvironmentSettingsRulesPage = nullptr;
+    CategoryWarning *mCategoryWarning = nullptr;
 };
 
 #endif // KDEBUGSETTINGSDIALOG_H
